Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1875)

Unified Diff: Source/core/workers/WorkerReportingProxy.h

Issue 1115923002: workers: Rename WorkerThread to WorkerScript. Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: . Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/core/workers/WorkerReportingProxy.h
diff --git a/Source/core/workers/WorkerReportingProxy.h b/Source/core/workers/WorkerReportingProxy.h
index 85e880654140531c24a92b6a02a4cf1c27594f8c..b09e767fd8af97e9a646bb3c6cb94e43ad6d65a6 100644
--- a/Source/core/workers/WorkerReportingProxy.h
+++ b/Source/core/workers/WorkerReportingProxy.h
@@ -61,10 +61,10 @@ public:
// Invoked when close() is invoked on the worker context.
virtual void workerGlobalScopeClosed() = 0;
// Invoked when the thread is stopped and WorkerGlobalScope is being
// destructed. (This is be the last method that is called on this
// interface)
- virtual void workerThreadTerminated() = 0;
+ virtual void workerScriptTerminated() = 0;
// Invoked when the thread is about to be stopped and WorkerGlobalScope
// is to be destructed. (When this is called it is guaranteed that
@@ -61,10 +61,10 @@ public:
// Invoked when close() is invoked on the worker context.
virtual void workerGlobalScopeClosed() = 0;
- // Invoked when the thread is stopped and WorkerGlobalScope is being
+ // Invoked when the WorkerScript is stopped and WorkerGlobalScope is being
// destructed. (This is be the last method that is called on this
// interface)

Powered by Google App Engine
This is Rietveld 408576698